﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using Infragistics.Controls.Charts;
using Infragistics.Windows;
using Infragistics.Controls;
using System.Diagnostics;

namespace DataChartZooming
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            DataContext = Data.GetData(15, 20, 50);
        }
    
        bool test = false;
        double scaleH = -1;
        double scaleV = -1;
        double positionH = -1;
        double positionV = -1;

        private void xmLineChart_PreviewMouseWheel(object sender, MouseWheelEventArgs e)
        {
            test = true;
            scaleH = xmLineChart.WindowScaleHorizontal;
            scaleV = xmLineChart.WindowScaleVertical;
            positionH = xmLineChart.WindowPositionHorizontal;
            positionV = xmLineChart.WindowPositionVertical;
        }

        private void xmZoombar_ZoomChanging(object sender, ZoomChangeEventArgs e)
        {
            if (test)
            {
                e.Cancel = true;
                test = false;
                xmLineChart.WindowScaleHorizontal = scaleH;
                xmLineChart.WindowScaleVertical = scaleV;
                xmLineChart.WindowPositionHorizontal = positionH;
                xmLineChart.WindowPositionVertical = positionV;
            }
        }

        private void xmLineChart_Loaded(object sender, RoutedEventArgs e)
        {
            ContentPresenter cp = Utilities.GetDescendantFromName(sender as DependencyObject, "ContentPresenter") as ContentPresenter;
            Border chartArea = (cp.Content as Panel).Children[2] as Border;
            chartArea.MouseLeftButtonDown += new MouseButtonEventHandler(chartArea_MouseLeftButtonDown);
            chartArea.MouseRightButtonDown += new MouseButtonEventHandler(chartArea_MouseRightButtonDown);
        }

        void chartArea_MouseRightButtonDown(object sender, MouseButtonEventArgs e)
        {
            Point position = e.GetPosition(sender as IInputElement);

            double positionX = (position.X / (sender as Border).ActualWidth) * 100;
            double positionY = (position.Y / (sender as Border).ActualHeight) * 100;

            xmLineChart.WindowRect = new Rect(positionX, positionY, xmLineChart.WindowRect.Width + .02, xmLineChart.WindowRect.Height + .02);
        }

        void chartArea_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
           Point position = e.GetPosition(sender as IInputElement);

           double positionX = ((position.X / (sender as Border).ActualWidth) * 100) / 100;
           double positionY = ((position.Y / (sender as Border).ActualHeight) * 100) / 100;

           xmLineChart.WindowRect = new Rect(positionX, positionY, xmLineChart.WindowRect.Width - .02, xmLineChart.WindowRect.Height - .02);
        }
    }
    
    public class Data : INotifyPropertyChanged
    {
        private int val;
        private int val1;
        private int val2;
        private string label;

        public int Value
        {
            get { return val; }
            set 
            { 
                val = value;
                PropChanged("Value");
            }
        }

        public int Value1
        {
            get { return val1; }
            set
            {
                val1 = value;
                PropChanged("Value1");
            }
        }

        public int Value2
        {
            get { return val2; }
            set
            {
                val2 = value;
                PropChanged("Value2");
            }
        }

        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }


        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data { 
                    Label = "Item " + i,
                    Value = r.Next(rangeStart, rangeEnd),
                    Value1 = r.Next(rangeStart, rangeEnd),
                    Value2 = r.Next(rangeStart, rangeEnd)
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }
}
